@@ -387,7 +387,7 @@ processtype message_from_name_explist(char *in_name, explisttype in_exl)
 	  "    }\n"
 	  "  }\n"
 	  
-	  ,in_name);
+	  ,in_name,in_name);
   code=app(code,instr(strclone(sacc)));
   out_message.local=code;
   out_message.global=emptysem();
@@ -655,7 +655,7 @@ sem *program_from_process(processtype in_proc)
   }
 
   code=instr(
-#include "header.c"
+#include "header.sc"
 		);
   code=app(code,instr(
 "void sendalong0(value name_channel) {\n"
@@ -672,11 +672,11 @@ sem *program_from_process(processtype in_proc)
 				   )).local);
   code=app(code,instr(
 "}\n\n"
-#include "serverdef.c"
+#include "serverdef.sc"
 		      ));
   code=app(code,in_proc.global);
   code=app(code,instr(                   "main()\n{\n"
-#include "serverinc.c"
+#include "serverinc.sc"
 		      ));
   code=app(code,in_proc.local);
   code=app(code,instr(
